==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_nn.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_nn extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "GBP", "GBP" },
            { "MRU", "MRU" },
            { "adp", "andorranske peseta" },
            { "afa", "afghani (1927\u20132002)" },
            { "aok", "angolske kwanza (1977\u20131990)" },
            { "aon", "angolske nye kwanza (1990\u20132000)" },
            { "aor", "angolske kwanza reajustado (1995\u20131999)" },
            { "ara", "argentiske austral" },
            { "arp", "argentinske peso (1983\u20131985)" },
            { "ats", "austerrikske schilling" },
            { "azm", "aserbaijanske manat" },
            { "bad", "bosnisk-hercegovinske dinarar" },
            { "bec", "belgiske franc (konvertibel)" },
            { "bel", "belgiske franc (finansiell)" },
            { "bgl", "bulgarsk hard lev" },
            { "bhd", "bahrainske dinarar" },
            { "bop", "boliviske peso" },
            { "bov", "boliviske mvdol" },
            { "brb", "brasiliansk cruzeiro novo (1967\u20131986)" },
            { "brc", "brasilianske cruzado" },
            { "brn", "brasilianske cruzado novo" },
            { "brr", "brasilianske cruzeiro" },
            { "buk", "burmesisk kyat" },
            { "byb", "kviterussiske nye rublar (1994\u20131999)" },
            { "byn", "nye kviterussiske rublar" },
            { "byr", "kviterussiske rublar (2000\u20132016)" },
            { "cop", "kolombianske pesos" },
            { "cou", "unidad de valor real" },
            { "crc", "kostarikanske col\u00f3n" },
            { "csd", "gamle serbiske dinarer" },
            { "cve", "kappverdiske escudo" },
            { "ddm", "austtyske mark" },
            { "dzd", "algeriske dinarar" },
            { "ghc", "ghanesiske cedi (1979\u20132007)" },
            { "grd", "greske drakme" },
            { "gwp", "Guinea-Bissau-peso" },
            { "hrd", "kroatiske dinar" },
            { "huf", "ungarske forintar" },
            { "idr", "indonesiske rupiar" },
            { "ils", "nye israelske sheklar" },
            { "inr", "indiske rupiar" },
            { "iqd", "irakiske dinarar" },
            { "irr", "iranske rial" },
            { "jod", "jordanske dinarar" },
            { "kwd", "kuwaitiske dinarar" },
            { "lkr", "srilankiske rupiar" },
            { "ltl", "litauiske lita" },
            { "ltt", "litauiske talona" },
            { "luc", "luxemburgske konvertibel franc" },
            { "lvl", "latviske lat" },
            { "lvr", "latviske rublar" },
            { "lyd", "libyske dinarar" },
            { "mdl", "moldovske leuar" },
            { "mkd", "makedonske denarar" },
            { "mur", "mauritiske rupiar" },
            { "mxp", "meksikanske s\u00f8lvpeso (1861\u20131992)" },
            { "nic", "nicaraguanske cordoba" },
            { "npr", "nepalske rupiar" },
            { "nzd", "nyzealandske dollar" },
            { "omr", "omanske rial" },
            { "pkr", "pakistanske rupiar" },
            { "pyg", "paraguayanske guaran\u00ed" },
            { "qar", "qatarske rial" },
            { "rol", "gamle rumenske leu" },
            { "ron", "rumenske leuar" },
            { "rsd", "serbiske dinarar" },
            { "rub", "russiske rublar" },
            { "rur", "russiske rublar (1991\u20131998)" },
            { "sar", "saudiarabiske rial" },
            { "scr", "seychelliske rupiar" },
            { "sdd", "gamle sudanske dinarer" },
            { "sdp", "gamle sudanske pund" },
            { "sur", "sovjetiske rublar" },
            { "szl", "eswatinisk lilangeni" },
            { "tjr", "tadsjikiske rublar" },
            { "tmm", "turkmensk manat (1993\u20132009)" },
            { "tnd", "tunisiske dinarar" },
            { "trl", "gamle tyrkiske lire" },
            { "uss", "amerikanske dollar (same dag)" },
            { "uyi", "uruguayanske peso en unidades indexadas" },
            { "uyp", "uruguayanske peso (1975\u20131993)" },
            { "uzs", "usbekiske sum" },
            { "vuv", "vanuatuiske vatu" },
            { "xba", "europeiske samansette einingar" },
            { "xbb", "europeiske monet\u00e6re einingar" },
            { "xbc", "europeiske kontoeiningar (XBC)" },
            { "xbd", "europeiske kontoeiningar (XBD)" },
            { "xcd", "austkaribiske dollar" },
            { "xdr", "spesielle trekkrettar" },
            { "xeu", "europeiske valutaeiningar" },
            { "xxx", "ukjend valuta" },
            { "ydd", "jemenittiske dinarar" },
            { "yer", "jemenittiske rial" },
            { "yud", "jugoslaviske dinarar (hard)" },
            { "yum", "jugoslaviske noviy-dinarar" },
            { "yun", "jugoslaviske konvertibel dinarar" },
            { "zal", "s\u00f8rafrikanske rand (finansiell)" },
            { "zrn", "zairisk ny zaire" },
            { "zrz", "zairisk zaire" },
            { "zwd", "zimbabwisk dollar" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_nn.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_nn extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "GBP", "GBP" },
            { "adp", "andorranske peseta" },
            { "afa", "afghanske afghani (1927\u20132002)" },
            { "aok", "angolske kwanza (1977\u20131990)" },
            { "aon", "angolske nye kwanza (1990\u20132000)" },
            { "aor", "angolske kwanza reajustado (1995\u20131999)" },
            { "ara", "argentiske austral" },
            { "arp", "argentinske peso (1983\u20131985)" },
            { "ats", "austerrikske schilling" },
            { "awg", "arubiske florinar" },
            { "bad", "bosnisk-hercegovinske dinarar (1992\u20131994)" },
            { "ban", "nye bosnisk-hercegovinske dinarar (1994\u20131997)" },
            { "bec", "belgiske franc (konvertibel)" },
            { "bel", "belgiske franc (finansiell)" },
            { "bgl", "bulgarsk hard lev" },
            { "bhd", "bahrainske dinarar" },
            { "bop", "boliviske peso" },
            { "bov", "boliviske mvdol" },
            { "brb", "brasiliansk cruzeiro novo (1967\u20131986)" },
            { "brc", "brasilianske cruzado" },
            { "brn", "brasilianske cruzado novo" },
            { "brr", "brasilianske cruzeiro" },
            { "buk", "burmesisk kyat" },
            { "byb", "belarusiske nye rublar (1994\u20131999)" },
            { "byn", "nye belarusiske rublar" },
            { "byr", "belarusiske rublar (2000\u20132016)" },
            { "che", "WIR-euro" },
            { "chw", "WIR-franc" },
            { "cop", "kolombianske pesos" },
            { "cou", "unidad de valor real" },
            { "crc", "kostarikanske col\u00f3n" },
            { "csd", "gamle serbiske dinarer" },
            { "cve", "kappverdiske escudo" },
            { "ddm", "austtyske mark" },
            { "dzd", "algeriske dinarar" },
            { "ghc", "ghanesiske cedi (1979\u20132007)" },
            { "grd", "greske drakme" },
            { "gwp", "Guinea-Bissau-peso" },
            { "hrd", "kroatiske dinar" },
            { "huf", "ungarske forintar" },
            { "idr", "indonesiske rupiahar" },
            { "ils", "nye israelske sheklar" },
            { "inr", "indiske rupiar" },
            { "iqd", "irakiske dinarar" },
            { "irr", "iranske rial" },
            { "jod", "jordanske dinarar" },
            { "kwd", "kuwaitiske dinarar" },
            { "lkr", "srilankiske rupiar" },
            { "ltl", "litauiske lita" },
            { "ltt", "litauiske talona" },
            { "luc", "luxemburgske konvertibel franc" },
            { "lvl", "latviske lat" },
            { "lvr", "latviske rublar" },
            { "lyd", "libyske dinarar" },
            { "mdl", "moldovske leuar" },
            { "mkd", "makedonske denarar" },
            { "mkn", "makedonske denarar (1992\u20131993)" },
            { "mur", "mauritiske rupiar" },
            { "mvp", "maldiviske rupiar" },
            { "mxp", "meksikanske s\u00f8lvpeso (1861\u20131992)" },
            { "nic", "nicaraguanske cordoba" },
            { "npr", "nepalske rupiar" },
            { "nzd", "nyzealandske dollar" },
            { "omr", "omanske rial" },
            { "pkr", "pakistanske rupiar" },
            { "pyg", "paraguayanske guaran\u00ed" },
            { "qar", "qatarske rial" },
            { "rol", "gamle rumenske leu" },
            { "ron", "rumenske leuar" },
            { "rsd", "serbiske dinarar" },
            { "rub", "russiske rublar" },
            { "rur", "russiske rublar (1991\u20131998)" },
            { "sar", "saudiarabiske rial" },
            { "scr", "seychelliske rupiar" },
            { "sdd", "gamle sudanske dinarer" },
            { "sdp", "gamle sudanske pund" },
            { "sle", "sierraleonske leonar" },
            { "sll", "sierraleonske leonar (1964\u20142022)" },
            { "sur", "sovjetiske rublar" },
            { "szl", "eswatinisk lilangeni" },
            { "tjr", "tadsjikiske rublar" },
            { "tnd", "tunisiske dinarar" },
            { "trl", "gamle tyrkiske lire" },
            { "try", "tyrkiske lira" },
            { "uss", "amerikanske dollar (same dag)" },
            { "uyi", "uruguayanske peso en unidades indexadas" },
            { "uyp", "uruguayanske peso (1975\u20131993)" },
            { "uzs", "usbekiske sum" },
            { "vuv", "vanuatuiske vatu" },
            { "xba", "europeiske samansette einingar" },
            { "xbb", "europeiske monet\u00e6re einingar" },
            { "xbc", "europeiske kontoeiningar (XBC)" },
            { "xbd", "europeiske kontoeiningar (XBD)" },
            { "xcd", "austkaribiske dollar" },
            { "xdr", "spesielle trekkrettar" },
            { "xeu", "europeiske valutaeiningar" },
            { "xxx", "ukjend valuta" },
            { "ydd", "jemenittiske dinarar" },
            { "yer", "jemenittiske rial" },
            { "yud", "jugoslaviske dinarar (hard)" },
            { "yum", "jugoslaviske noviy-dinarar" },
            { "yun", "jugoslaviske konvertibel dinarar" },
            { "zal", "s\u00f8rafrikanske rand (finansiell)" },
            { "zrn", "zairisk ny zaire" },
            { "zrz", "zairisk zaire" },
            { "zwd", "zimbabwisk dollar" },
        };
        return data;
    }
}
